@@ -1,9 +1,9 @@
 #pragma once
 
-#define PROBE_VERSION "0.8.0"
+#define PROBE_VERSION "0.9.0"
 
 #define PROBE_NAME "sysdig-probe"
 
 #define PROBE_DEVICE_NAME "sysdig"
 
-#define PROBE_EVENT_DEVICE_NAME PROBE_DEVICE_NAME "-events"
+#define PROBE_EVENT_DEVICE_NAME "sysdig"
