@@ -418,6 +418,12 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define PPM_IPC_NOWAIT		(1 << 0)
 #define PPM_SEM_UNDO		(1 << 1)
 
+/*
+ * Semget flags
+ */
+#define PPM_IPC_CREAT  (1 << 13)
+#define PPM_IPC_EXCL   (1 << 14)
+
 #define PPM_IPC_STAT		(1 << 0)
 #define PPM_IPC_SET		(1 << 1)
 #define PPM_IPC_RMID		(1 << 2)
@@ -432,6 +438,14 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define PPM_SETALL		(1 << 11)
 #define PPM_SETVAL		(1 << 12)
 
+/*
+ * Access flags
+ */
+#define PPM_F_OK            (0)
+#define PPM_X_OK            (1 << 0)
+#define PPM_W_OK            (1 << 1)
+#define PPM_R_OK            (1 << 2)
+
 /*
  * SuS says limits have to be unsigned.
  * Which makes a ton more sense anyway.
@@ -735,7 +749,21 @@ enum ppm_event_type {
 	PPME_SYSCALL_MOUNT_X = 257,
 	PPME_SYSCALL_UMOUNT_E = 258,
 	PPME_SYSCALL_UMOUNT_X = 259,
-	PPM_EVENT_MAX = 260
+	PPME_K8S_E = 260,
+	PPME_K8S_X = 261,
+	PPME_SYSCALL_SEMGET_E = 262,
+	PPME_SYSCALL_SEMGET_X = 263,
+	PPME_SYSCALL_ACCESS_E = 264,
+	PPME_SYSCALL_ACCESS_X = 265,
+	PPME_SYSCALL_CHROOT_E = 266,
+	PPME_SYSCALL_CHROOT_X = 267,
+	PPME_TRACER_E = 268,
+	PPME_TRACER_X = 269,
+	PPME_MESOS_E = 270,
+	PPME_MESOS_X = 271,
+	PPME_CONTAINER_JSON_E = 272,
+	PPME_CONTAINER_JSON_X = 273,
+	PPM_EVENT_MAX = 274
 };
 /*@}*/
 
@@ -1097,23 +1125,7 @@ enum ppm_event_flags {
 	EF_UNUSED = (1 << 6), /* This event is not used */
 	EF_WAITS = (1 << 7), /* This event reads data from an FD. */
 	EF_SKIPPARSERESET = (1 << 8), /* This event shouldn't pollute the parser lastevent state tracker. */
-	EF_OLD_VERSION = (1 << 9) /* This event is kept for backward compatibility */
-};
-
-/*
- * Operators to compare events
- */
-enum ppm_cmp_operator {
-	CO_NONE = 0,
-	CO_EQ = 1,
-	CO_NE = 2,
-	CO_LT = 3,
-	CO_LE = 4,
-	CO_GT = 5,
-	CO_GE = 6,
-	CO_CONTAINS = 7,
-	CO_IN = 8,
-	CO_EXISTS = 9,
+	EF_OLD_VERSION = (1 << 9), /* This event is kept for backward compatibility */
 };
 
 /*
@@ -1155,7 +1167,10 @@ enum ppm_param_type {
 	PT_GID = 32, /* this is an UINT32, MAX_UINT32 will be interpreted as no value. */
 	PT_DOUBLE = 33, /* this is a double precision floating point number. */
 	PT_SIGSET = 34, /* sigset_t. I only store the lower UINT32 of it */
-	PT_MAX = 35 /* array size */
+	PT_CHARBUFARRAY = 35,	/* Pointer to an array of strings, exported by the user events decoder. 64bit. For internal use only. */
+	PT_CHARBUF_PAIR_ARRAY = 36,	/* Pointer to an array of string pairs, exported by the user events decoder. 64bit. For internal use only. */
+	PT_IPV4NET = 37, /* An IPv4 network. */
+	PT_MAX = 38 /* array size */
 };
 
 enum ppm_print_format {
@@ -1275,7 +1290,9 @@ extern const struct ppm_name_value quotactl_types[];
 extern const struct ppm_name_value quotactl_dqi_flags[];
 extern const struct ppm_name_value quotactl_quota_fmts[];
 extern const struct ppm_name_value semop_flags[];
+extern const struct ppm_name_value semget_flags[];
 extern const struct ppm_name_value semctl_commands[];
+extern const struct ppm_name_value access_flags[];
 
 
 extern const struct ppm_param_info ptrace_dynamic_param[];
